Range-v3: range/v3/iterator_range.hpp File Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Classes | Functions | Variables
iterator_range.hpp File Reference

## Classes
struct | ranges::v3::iterator_range< I, S >
struct | ranges::v3::make_iterator_range_fn
struct | ranges::v3::sized_iterator_range< I, S >

## Functions
template<std::size_t N, typename I , typename S , requires = (N < 2)>
constexpr auto | ranges::v3::get (sized_iterator_range< I, S > const &p) -> decltype(ranges::get< N >(static_cast< iterator_range< I, S > const &>(p)))
| Tuple-like access for `sized_iterator_range`
template<std::size_t N, typename I , typename S , requires = (N == 2)>
constexpr size_type_t< I > | ranges::v3::get (sized_iterator_range< I, S > const &p)

## Variables
constexpr make_iterator_range_fn | ranges::v3::make_iterator_range {}

## Function Documentation

## ◆ get()

template<std::size_t N, typename I , typename S , requires = (N == 2)>

constexpr size_type_t<I> ranges::v3::get | ( | sized_iterator_range< I, S > const & | p | ) |

This is an overloaded member function, provided for convenience. It differs from the above function only in what argument(s) it accepts.